@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -149,7 +149,7 @@ command_replace (GtkWidget *widget,
 
 
 void
-command_conf (GtkWidget *widget,
+command_pref (GtkWidget *widget,
               gpointer   user_data);
 
 
