@@ -236,7 +236,7 @@ main (int   argc,
       second = g_key_file_get_boolean (key_file, "pref", "second", NULL);
       def_width = g_key_file_get_integer (key_file, "pref", "width", NULL);
       def_height = g_key_file_get_integer (key_file, "pref", "height", NULL);
-      n_pos = g_key_file_get_integer (key_file, "pref", "n_pos", NULL);
+      n_pos = g_key_file_get_integer (key_file, "pref", "npos", NULL);
       ftnum = g_key_file_get_integer (key_file, "tmaid", "ftnum", NULL);
 #if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
       findex = g_key_file_get_integer (key_file, "tmaid", "findex", NULL);
@@ -736,7 +736,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
       g_key_file_set_boolean (key_file, "pref", "second", second);
       g_key_file_set_integer (key_file, "pref", "width", def_width);
       g_key_file_set_integer (key_file, "pref", "height", def_height);
-      g_key_file_set_integer (key_file, "pref", "n_pos", n_pos);
+      g_key_file_set_integer (key_file, "pref", "npos", n_pos);
       g_key_file_set_integer (key_file, "tmaid", "ftnum", ftnum);
 #if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
       for (i = ftnum - 1; i >= 0; i--)
